<?php
/**
 * Creare Magazin Online functions and definitions
 *
 * @package Creare Magazin Online

 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 670; /* pixels */
}

if ( ! function_exists( 'crearemagazinonline_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function crearemagazinonline_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Creare Magazin Online, use a find and replace
	 * to change 'creare-magazin-online' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'creare-magazin-online', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'menu-1' => __( 'Primary Menu', 'creare-magazin-online' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
	
 
	
	add_theme_support( 'post-thumbnails' );
	
	//add_editor_style();
}
endif; // crearemagazinonline_setup
add_action( 'after_setup_theme', 'crearemagazinonline_setup' );




function crearemagazinonline_content_wrap($content) {
    $content = '<div class="widgetcontent">'.$content.'</div>';
    return $content;
}
add_filter('widget_text', 'crearemagazinonline_content_wrap');


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function crearemagazinonline_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'creare-magazin-online' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => sprintf( "%1s %1d &rarr; %2s" , __( 'Footer', 'creare-magazin-online' ), 1, __( 'Left', 'creare-magazin-online' ) ),
		'id'            => 'footer-left',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => sprintf( "%1s %1d &rarr; %2s" , __( 'Footer', 'creare-magazin-online' ), 2, __( 'Center', 'creare-magazin-online' ) ),
		'id'            => 'footer-center',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => sprintf( "%1s %1d &rarr; %2s" , __( 'Footer', 'creare-magazin-online' ), 3, __( 'Right', 'creare-magazin-online' ) ),
		'id'            => 'footer-right',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'crearemagazinonline_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function crearemagazinonline_theme_scripts() {	
	wp_enqueue_style( 'crearemagazinonline-font-awesome',get_template_directory_uri().'/font-awesome/css/font-awesome.min.css',array() );
	wp_enqueue_style( 'crearemagazinonline-google-fonts','//fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,700',array() );
	
	wp_enqueue_script( 'crearemagazinonline-mobilemenu', get_template_directory_uri() . '/js/jquery.mobilemenu.min.js', array(), '1', true );

	wp_enqueue_script( 'crearemagazinonline-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	
	wp_enqueue_script( 'crearemagazinonline-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array('jquery'), '' );
	wp_enqueue_script( 'crearemagazinonline-fitvids-doc-ready', get_template_directory_uri() . '/js/fitvids-doc-ready.js', array('jquery'), '' );
	
	wp_enqueue_style( 'crearemagazinonline-style', get_stylesheet_uri() );
		
	wp_enqueue_script( 'crearemagazinonline-basejs',get_template_directory_uri().'/js/base.js',array('jquery'),'' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	/**
	 * Register JQuery cycle js file for slider.
	 */
	wp_register_script( 'jquery-cycle', get_template_directory_uri() . '/js/jquery.cycle.all.min.js', array( 'jquery' ), '2.9999.5', true );

	/**
	 * Enqueue Slider setup js file.
	 */	
	if( get_theme_mod( 'enable_slider', 1 ) && ( is_home() || is_front_page() ) ) { 
		wp_enqueue_script( 'crearemagazinonline_slider', get_template_directory_uri() . '/js/slider-setting.js', array( 'jquery-cycle' ), false, true );
	}
	
	/**
    * Browser specific queuing i.e
	* https://gist.github.com/grappler/05568f05633484499acc
    */
	global $wp_scripts;
	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5shiv.min.js', array(), '3.7.2', false );
	$wp_scripts->add_data( 'html5shiv', 'conditional', 'lt IE 9' );

}
add_action( 'wp_enqueue_scripts', 'crearemagazinonline_theme_scripts' );

 

/**
 * Hooks the Custom Internal CSS to head section
 */
function crearemagazinonline_custom_css() {
	$images = get_template_directory_uri() . "/images/";
	$crearemagazinonline_internal_css = '';

	$primary_color = esc_attr( get_theme_mod( 'primary_color', '#00B0C8' ) );	
	if( $primary_color != '#00B0C8' ) {
		$crearemagazinonline_internal_css .= '
		blockquote, pre {
			border-left:2px solid '.$primary_color.';
		}';
		// Bg Color
		$crearemagazinonline_internal_css .= '
		button,input[type="button"],input[type="reset"],input[type="submit"],
		#controllers a:hover, #controllers a.active,
		#slider-title a {
			background-color:'.$primary_color.';
		}';
		// Color
		$crearemagazinonline_internal_css .= '
		.entry-title, .entry-title a, .widget-area .widget-title,
		#controllers a:hover, #controllers a.active,
		a:hover,a:focus,a:active,
		.pagination .nav-links a:hover,
		.pagination .current,
		.entry-content a,
		.wp-pagenavi span.current{
			color:'.$primary_color.';
		}
		';
		
	}
	// Content background-image & Colour
	if ( get_theme_mod( 'content_bg' ) )
		$crearemagazinonline_internal_css .= ".site-content{background-image:url(".esc_attr(get_theme_mod( 'content_bg')).");}";
	if ( get_theme_mod( 'content_bg_color') )
		$crearemagazinonline_internal_css .= ".site-content{background-color:".esc_attr(get_theme_mod( 'content_bg_color')).";}";
	
	// Post
	if ( get_theme_mod( 'posts_font_size') )
		$crearemagazinonline_internal_css .= ".entry-content{font-size:".esc_attr(get_theme_mod( 'posts_font_size'))."px;}";
	if ( get_theme_mod( 'posts_font_color') )
		$crearemagazinonline_internal_css .= ".entry-content{color:".esc_attr(get_theme_mod( 'posts_font_color')).";}";
	if ( get_theme_mod( 'posts_link_color') )
		$crearemagazinonline_internal_css .= ".entry-content a {color:".esc_attr(get_theme_mod( 'posts_link_color')).";}";
	if ( get_theme_mod( 'meta_color') )
		$crearemagazinonline_internal_css .= ".entry-footer,.entry-footer span a,.entry-meta,.entry-meta span a {color:".esc_attr(get_theme_mod( 'meta_color')).";}";
	
	// Menu
	if ( get_theme_mod( 'menu_font_color') )
		$crearemagazinonline_internal_css .= ".nav-menu > li a {color:".esc_attr(get_theme_mod( 'menu_font_color')).";}";
	if ( get_theme_mod( 'menu_font_color_hover') ) {
		$crearemagazinonline_internal_css .= ".main-navigation .nav-menu > li > a:hover{ color:".esc_attr(get_theme_mod( 'menu_font_color_hover')).";}";
		$crearemagazinonline_internal_css .= ".main-navigation .nav-menu > li span { background-color:".esc_attr(get_theme_mod( 'menu_font_color_hover')).";}";
	}
	if ( get_theme_mod( 'menu_bg_image' ) )
		$crearemagazinonline_internal_css .= ".main-navigation{background:url(".esc_url(get_theme_mod( 'menu_bg_image')).")left bottom;}";
	
	// Widgets background-image & Colour
	if ( get_theme_mod( 'widgets_bg' ) )
		$crearemagazinonline_internal_css .= ".widget-area .widget {
			background-image:url( " . esc_url(get_theme_mod( 'widgets_bg' )) . " );
			}";
	if ( get_theme_mod( 'widgets_bg_color') )
		$crearemagazinonline_internal_css .= ".widget-area .widget {background-color:".esc_url(get_theme_mod( 'widgets_bg_color')).";}";
	 
	// Header Text Color
	if ( ! get_theme_mod('logo') )
		$crearemagazinonline_internal_css .= ".site-title a{color:#".esc_attr(get_theme_mod( 'header_textcolor')).";}";
	

	
	// Custom CSS
		$crearemagazinonline_internal_css .= esc_html(get_theme_mod( 'css'));
	// Print Inline Styles
	if( !empty( $crearemagazinonline_internal_css ) ) { ?><style type="text/css"><?php echo $crearemagazinonline_internal_css; ?></style><?php }
}
add_action('wp_head', 'crearemagazinonline_custom_css');

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Theme Options Panel
 */
require get_template_directory() . '/inc/theme-options.php';

/**
 * Slider
 */
require_once( get_template_directory() . '/inc/header-functions.php' );
?>
